@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from audio import AudioHandler
 from base import LanguageHandler, NullHandler
 from text import SingleSentenceHandler
 
 __all__ = [
-    "AudioHandler",
     "LanguageHandler",
     "NullHandler",
     "SingleSentenceHandler",
