@@ -48,6 +48,18 @@ DATA_SET = [
           u""),
          2]
     ),
+    (
+        [u"previous sentence.\n",
+         u"\n",
+         u"*******\n",
+         u"feature\n",
+         u"*******\n",
+         u""],
+        [(None,
+          [],
+          u""),
+         0]
+    ),
     (
         [u"subsection\n",
          u"----------\n",
